@@ -1,8 +1,8 @@
-package Dist::Zilla::Plugin::Test::NoTabs; # git description: v0.10-4-g9cef652
+package Dist::Zilla::Plugin::Test::NoTabs; # git description: v0.11-1-g9cc9b87
 # ABSTRACT: Author tests that ensure hard tabs are not used
 # KEYWORDS: plugin test testing author development whitespace tab tabstop indent formatting
 # vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::Plugin::Test::NoTabs::VERSION = '0.11';
+$Dist::Zilla::Plugin::Test::NoTabs::VERSION = '0.12';
 use Moose;
 use Path::Tiny;
 use Sub::Exporter::ForMethods 'method_installer'; # method_installer returns a sub.
@@ -118,7 +118,7 @@ sub munge_files
     my $self = shift;
 
     my @filenames = map { path($_->name)->relative('.')->stringify }
-        grep { $_->can('is_bytes') and not $_->is_bytes }
+        grep { not ($_->can('is_bytes') and $_->is_bytes) }
         @{ $self->found_files };
     push @filenames, $self->files;
 
@@ -200,7 +200,7 @@ Dist::Zilla::Plugin::Test::NoTabs - Author tests that ensure hard tabs are not u
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
